import * as acm from "aws-cdk-lib/aws-certificatemanager";
import * as cloudfront from "aws-cdk-lib/aws-cloudfront";
import * as origins from "aws-cdk-lib/aws-cloudfront-origins";
import * as route53 from "aws-cdk-lib/aws-route53";
import * as s3 from "aws-cdk-lib/aws-s3";
import { Construct } from "constructs";
import { CloudFrontToOriginsProps, S3OriginInfo, HttpOriginInfo } from "./interface";
export declare class CloudFrontToOrigins extends Construct {
    readonly distribution: cloudfront.Distribution;
    readonly logBucket?: s3.IBucket;
    readonly certificate?: acm.ICertificate;
    readonly aRecord?: route53.ARecord;
    readonly domainNames?: string[];
    private readonly s3BucketsMap;
    private readonly httpOriginsMap;
    constructor(scope: Construct, id: string, props: CloudFrontToOriginsProps);
    /**
     * Validate that all origin IDs are unique
     */
    private validateOriginIds;
    /**
     * Apply intelligent defaults based on origin configuration
     */
    private applyDefaults;
    /**
     * Defaults for S3-only static website
     */
    private getS3WebsiteDefaults;
    /**
     * Defaults for HTTP-only proxy/API
     */
    private getHttpProxyDefaults;
    /**
     * Defaults for hybrid S3 + HTTP distribution
     */
    private getHybridDefaults;
    /**
     * Setup HTTP origin
     */
    private setupHttpOrigin;
    /**
     * Setup custom domain and certificate
     */
    private setupCustomDomain;
    /**
     * Setup CloudFront logging
     */
    private setupLogging;
    /**
     * Get origin by ID
     */
    private getOriginById;
    /**
     * Determine default origin ID
     */
    private getDefaultOriginId;
    /**
     * Create CloudFront distribution
     */
    private createDistribution;
    /**
     * Setup Route53 alias record
     */
    private setupRoute53Record;
    /**
     * Get S3 bucket by origin ID
     */
    getS3Bucket(originId: string): s3.IBucket | undefined;
    /**
     * Get HTTP origin by origin ID
     */
    getHttpOrigin(originId: string): origins.HttpOrigin | undefined;
    /**
     * Get all S3 bucket origin IDs
     */
    get s3OriginIds(): string[];
    /**
     * Get all HTTP origin IDs
     */
    get httpOriginIds(): string[];
    /**
     * Get all S3 buckets as an array of objects with ID and bucket
     */
    get s3Origins(): S3OriginInfo[];
    /**
     * Get all HTTP origins as an array of objects with ID and origin
     */
    get httpOrigins(): HttpOriginInfo[];
    /**
     * Get the CloudFront distribution domain name
     */
    get distributionDomainName(): string;
    /**
     * Get the CloudFront distribution URL with protocol
     */
    get distributionUrl(): string;
    /**
     * Get the custom domain URL (if configured)
     */
    get customDomainUrl(): string | undefined;
}
